:mod:`fyzz.ast` -- SPARQL Abstract Syntax Tree
===============================================

.. automodule:: fyzz.ast

.. autoclass:: fyzz.ast.SparqlTree
.. autoclass:: fyzz.ast.SparqlVar
.. autoclass:: fyzz.ast.SparqlLiteral

